import colors

def banner():
    return(colors.cyan + '\n-=-=-=-=-=- Whiteboard -=-=-=-=-=-\n' + colors.white)
    
def footer():
    return(colors.cyan + '\n-=-=-=-=-=-=-=-=-=-=-=-=-=--=-=-=-\n' + colors.white)